@@ -1,8 +1,10 @@
 module Hat.CPUTime (ggetCPUTime,gcpuTimePrecision) where
 
-import qualified Prelude 
-import qualified Hat.Hat as T 
 import qualified Hat.PreludeBasic 
+import qualified Prelude 
+import Hat.Hack 
+import qualified Hat.Hat as T 
+import Hat.Hat  (WrapVal(wrapVal))
 import Hat.Prelude 
 import Hat.PreludeBuiltinTypes 
 import qualified CPUTime 
@@ -26,7 +28,7 @@ scpuTimePrecision =
 
 tCPUTime = T.mkModule "CPUTime" "CPUTime.hs" Prelude.False
 
-agetCPUTime = T.mkVariable tCPUTime 70002 3 0 "getCPUTime" Prelude.False
+agetCPUTime = T.mkVariable tCPUTime 60001 70024 3 0 "getCPUTime" Prelude.False
 
 acpuTimePrecision =
-  T.mkVariable tCPUTime 100002 3 0 "cpuTimePrecision" Prelude.False
+  T.mkVariable tCPUTime 90001 100029 3 0 "cpuTimePrecision" Prelude.False
