@@ -125,7 +125,7 @@ gconjugate pconjugate p = T.ufun1 aconjugate pconjugate p hconjugate
 
 hconjugate (T.R (fx :+ fy) _) p =
   T.con2 T.mkNoSrcPos p (:+) (+:+) fx
-    (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p) fy)
+    (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p) fy)
 hconjugate _ p = T.fatal p
 
 gmkPolar ::
@@ -208,8 +208,7 @@ hmagnitude (T.R (fx :+ fy) _) p =
   smk =
     T.uconstDef p a29v11v29v18mk
       (\ p ->
-        T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
-          (gk T.mkNoSrcPos p))
+        T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p) (gk T.mkNoSrcPos p))
   
 hmagnitude _ p = T.fatal p
 
@@ -394,7 +393,7 @@ instance RealFloat a => Fractional ((Complex a))
       sk =
         T.uconstDef p a51v5v51v42k
           (\ p ->
-            T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
+            T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p)
               (T.uap2 T.mkNoSrcPos p (gmax T.mkNoSrcPos p)
                 (T.uap1 T.mkNoSrcPos p (gexponent T.mkNoSrcPos p) fx')
                 (T.uap1 T.mkNoSrcPos p (gexponent T.mkNoSrcPos p) fy')))
@@ -493,8 +492,8 @@ instance RealFloat a => Floating ((Complex a))
             (T.uap1 T.mkNoSrcPos p
               (Hat.PreludeBasic.gfromInteger T.mkNoSrcPos p)
               (T.conInteger T.mkNoSrcPos p 0)))
-          (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
-            (gv T.mkNoSrcPos p)) (gv T.mkNoSrcPos p))
+          (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p) (gv T.mkNoSrcPos p))
+          (gv T.mkNoSrcPos p))
       where
       
       gu pu p = T.uconstUse pu p su
@@ -576,7 +575,7 @@ instance RealFloat a => Floating ((Complex a))
         (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !* p)
           (T.uap1 T.mkNoSrcPos p (gcos T.mkNoSrcPos p) fx)
           (T.uap1 T.mkNoSrcPos p (gcosh T.mkNoSrcPos p) fy))
-        (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
+        (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p)
           (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !* p)
             (T.uap1 T.mkNoSrcPos p (gsin T.mkNoSrcPos p) fx)
             (T.uap1 T.mkNoSrcPos p (gsinh T.mkNoSrcPos p) fy)))
@@ -597,7 +596,7 @@ instance RealFloat a => Floating ((Complex a))
         (T.con2 T.mkNoSrcPos p (:+) (+:+)
           (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !* p) (gcosx T.mkNoSrcPos p)
             (gcoshy T.mkNoSrcPos p))
-          (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
+          (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p)
             (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !* p) (gsinx T.mkNoSrcPos p)
               (gsinhy T.mkNoSrcPos p))))
       where
@@ -710,8 +709,7 @@ instance RealFloat a => Floating ((Complex a))
     
     hasin (fz@(T.R (fx :+ fy) _)) p =
       T.con2 T.mkNoSrcPos p (:+) (+:+) (gy' T.mkNoSrcPos p)
-        (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
-          (gx' T.mkNoSrcPos p))
+        (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p) (gx' T.mkNoSrcPos p))
       where
       
       gx' px' p = T.uconstUse px' p sx'
@@ -723,8 +721,7 @@ instance RealFloat a => Floating ((Complex a))
           T.uap1 T.mkNoSrcPos p (glog T.mkNoSrcPos p)
             (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !+ p)
               (T.con2 T.mkNoSrcPos p (:+) (+:+)
-                (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p) fy)
-                (T.projection T.mkNoSrcPos p fx))
+                (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p) fy) fx)
               (T.uap1 T.mkNoSrcPos p (gsqrt T.mkNoSrcPos p)
                 (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !- p)
                   (T.uap1 T.mkNoSrcPos p
@@ -751,8 +748,7 @@ instance RealFloat a => Floating ((Complex a))
     
     hacos (fz@(T.R (fx :+ fy) _)) p =
       T.con2 T.mkNoSrcPos p (:+) (+:+) (gy'' T.mkNoSrcPos p)
-        (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
-          (gx'' T.mkNoSrcPos p))
+        (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p) (gx'' T.mkNoSrcPos p))
       where
       
       gx'' px'' p = T.uconstUse px'' p sx''
@@ -764,7 +760,7 @@ instance RealFloat a => Floating ((Complex a))
           T.uap1 T.mkNoSrcPos p (glog T.mkNoSrcPos p)
             (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !+ p) fz
               (T.con2 T.mkNoSrcPos p (:+) (+:+)
-                (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
+                (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p)
                   (gy' T.mkNoSrcPos p)) (gx' T.mkNoSrcPos p))) of
           T.R (fx'' :+ fy'') kx'' -> (kx'',fx'',fy'')
           _ -> T.fatal p
@@ -809,8 +805,7 @@ instance RealFloat a => Floating ((Complex a))
     
     hatan (fz@(T.R (fx :+ fy) _)) p =
       T.con2 T.mkNoSrcPos p (:+) (+:+) (gy' T.mkNoSrcPos p)
-        (T.uap1 T.mkNoSrcPos p (Hat.Prelude.gnegate T.mkNoSrcPos p)
-          (gx' T.mkNoSrcPos p))
+        (T.uap1 T.mkNoSrcPos p (gnegate T.mkNoSrcPos p) (gx' T.mkNoSrcPos p))
       where
       
       gx' px' p = T.uconstUse px' p sx'
@@ -825,8 +820,7 @@ instance RealFloat a => Floating ((Complex a))
                 (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !- p)
                   (T.uap1 T.mkNoSrcPos p
                     (Hat.PreludeBasic.gfromInteger T.mkNoSrcPos p)
-                    (T.conInteger T.mkNoSrcPos p 1)) fy)
-                (T.projection T.mkNoSrcPos p fx))
+                    (T.conInteger T.mkNoSrcPos p 1)) fy) fx)
               (T.uap1 T.mkNoSrcPos p (gsqrt T.mkNoSrcPos p)
                 (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !+ p)
                   (T.uap1 T.mkNoSrcPos p
@@ -910,14 +904,6 @@ tComplex = T.mkModule "Complex" "Complex.hs" Prelude.False
 
 (+:+) = T.mkConstructor tComplex 60043 60044 24 2 ":+"
 
-(++=+!=+=+#==) = T.mkVariable tComplex 60060 60061 3 2 "==" Prelude.False
-
-a6v63v6v66readsPrec =
-  T.mkVariable tComplex 60063 60066 3 1 "readsPrec" Prelude.False
-
-a6v68v6v71showsPrec =
-  T.mkVariable tComplex 60068 60071 3 2 "showsPrec" Prelude.False
-
 arealPart = T.mkVariable tComplex 100001 100021 3 1 "realPart" Prelude.False
 
 aimagPart = T.mkVariable tComplex 110001 110021 3 1 "imagPart" Prelude.False
@@ -934,6 +920,14 @@ amagnitude = T.mkVariable tComplex 260001 290018 3 1 "magnitude" Prelude.False
 
 aphase = T.mkVariable tComplex 320001 330026 3 1 "phase" Prelude.False
 
+(++=+!=+=+#==) = T.mkVariable tComplex 60060 60061 3 2 "==" Prelude.False
+
+a6v63v6v66readsPrec =
+  T.mkVariable tComplex 60063 60066 3 1 "readsPrec" Prelude.False
+
+a6v68v6v71showsPrec =
+  T.mkVariable tComplex 60068 60071 3 2 "showsPrec" Prelude.False
+
 (+%^=#$=%^=#$+) = T.mkVariable tComplex 370012 370012 26 2 "+" Prelude.False
 
 (+%@=#$=%@=#$-) = T.mkVariable tComplex 380012 380012 26 2 "-" Prelude.False
