@@ -2,9 +2,11 @@ module Hat.Data.Bool
   (Bool(False,True),aFalse,aTrue,(!&&),(+&&),(*&&),(!||),(+||),(*||),gnot,anot
     ,hnot,gotherwise) where
 
-import qualified Prelude 
-import qualified Hat.Hat as T 
 import qualified Hat.PreludeBasic 
+import qualified Prelude 
+import Hat.Hack 
+import qualified Hat.Hat as T 
+import Hat.Hat  (WrapVal(wrapVal))
 import Hat.Prelude 
 
 tData_Bool = T.mkModule "Data.Bool" "Data/Bool.hs" Prelude.False
