@@ -1,9 +1,11 @@
 module Hat.Data.Either
   (Either(Left,Right),aLeft,aRight,geither,aeither,heither) where
 
-import qualified Prelude 
-import qualified Hat.Hat as T 
 import qualified Hat.PreludeBasic 
+import qualified Prelude 
+import Hat.Hack 
+import qualified Hat.Hat as T 
+import Hat.Hat  (WrapVal(wrapVal))
 import Hat.Prelude 
 
 tData_Either = T.mkModule "Data.Either" "Data/Either.hs" Prelude.False
