@@ -10,7 +10,8 @@ module Hat.Data.PackedString
     ,gtakeWhilePS,atakeWhilePS,htakeWhilePS,gdropWhilePS,adropWhilePS
     ,hdropWhilePS,gspanPS,aspanPS,hspanPS,gbreakPS,abreakPS,hbreakPS,glinesPS
     ,alinesPS,hlinesPS,gwordsPS,awordsPS,hwordsPS,gsplitPS,asplitPS,hsplitPS
-    ,gsplitWithPS,asplitWithPS,hsplitWithPS) where
+    ,gsplitWithPS,asplitWithPS,hsplitWithPS,gunlinesPS,aunlinesPS,hunlinesPS
+    ,gunwordsPS,aunwordsPS,hunwordsPS,gjoinPS,ajoinPS,hjoinPS) where
 
 import qualified Hat.PreludeBasic 
 import qualified Prelude 
@@ -392,6 +393,38 @@ hsplitWithPS z1splitWithPS z2splitWithPS ksplitWithPS =
       ((toFun T.fromChar toBool) ksplitWithPS z1splitWithPS)
       (toPackedString ksplitWithPS z2splitWithPS))
 
+gunlinesPS ::
+  T.RefSrcPos -> T.RefExp -> T.R (T.Fun (T.List PackedString) PackedString)
+
+gunlinesPS punlinesPS p = T.ufun1 aunlinesPS punlinesPS p hunlinesPS
+
+hunlinesPS z1unlinesPS kunlinesPS =
+  fromPackedString kunlinesPS
+    (Data.PackedString.unlinesPS
+      ((toList toPackedString) kunlinesPS z1unlinesPS))
+
+gunwordsPS ::
+  T.RefSrcPos -> T.RefExp -> T.R (T.Fun (T.List PackedString) PackedString)
+
+gunwordsPS punwordsPS p = T.ufun1 aunwordsPS punwordsPS p hunwordsPS
+
+hunwordsPS z1unwordsPS kunwordsPS =
+  fromPackedString kunwordsPS
+    (Data.PackedString.unwordsPS
+      ((toList toPackedString) kunwordsPS z1unwordsPS))
+
+gjoinPS ::
+  T.RefSrcPos ->
+    T.RefExp ->
+      T.R (T.Fun PackedString (T.Fun (T.List PackedString) PackedString))
+
+gjoinPS pjoinPS p = T.ufun2 ajoinPS pjoinPS p hjoinPS
+
+hjoinPS z1joinPS z2joinPS kjoinPS =
+  fromPackedString kjoinPS
+    (Data.PackedString.joinPS (toPackedString kjoinPS z1joinPS)
+      ((toList toPackedString) kjoinPS z2joinPS))
+
 tData_PackedString =
   T.mkModule "Data.PackedString" "Data/PackedString.hs" Prelude.False
 
@@ -413,15 +446,6 @@ aprimShowsPrecPackedString =
   T.mkVariable tData_PackedString 620001 630070 3 3 "primShowsPrecPackedString"
     Prelude.False
 
-(+++=&=++=%$==) =
-  T.mkVariable tData_PackedString 660004 660032 16 0 "==" Prelude.False
-
-(++@=&=+@=%$<=) =
-  T.mkVariable tData_PackedString 680004 680032 16 0 "<=" Prelude.False
-
-a70v3v70v39showsPrec =
-  T.mkVariable tData_PackedString 700003 700039 3 0 "showsPrec" Prelude.False
-
 anilPS = T.mkVariable tData_PackedString 720001 730032 3 0 "nilPS" Prelude.False
 
 aconsPS =
@@ -503,3 +527,21 @@ asplitPS =
 asplitWithPS =
   T.mkVariable tData_PackedString 1260001 1270053 3 2 "splitWithPS"
     Prelude.False
+
+aunlinesPS =
+  T.mkVariable tData_PackedString 1300001 1310050 3 1 "unlinesPS" Prelude.False
+
+aunwordsPS =
+  T.mkVariable tData_PackedString 1320001 1330050 3 1 "unwordsPS" Prelude.False
+
+ajoinPS =
+  T.mkVariable tData_PackedString 1340001 1350066 3 2 "joinPS" Prelude.False
+
+(+++=&=++=%$==) =
+  T.mkVariable tData_PackedString 660004 660032 16 0 "==" Prelude.False
+
+(++@=&=+@=%$<=) =
+  T.mkVariable tData_PackedString 680004 680032 16 0 "<=" Prelude.False
+
+a70v3v70v39showsPrec =
+  T.mkVariable tData_PackedString 700003 700039 3 0 "showsPrec" Prelude.False
