@@ -25,6 +25,65 @@ instance T.WrapVal ((Set a))
     T.R kwrapVal (T.mkValueApp1 p pwrapVal aMkSet z1wrapVal)
   
 
+instance Show a => Show ((Set a))
+  where
+  
+  gshow pshow p =
+    T.ufun1 a30v3v37v54show pshow p hshow
+    where
+    
+    hshow fs p =
+      T.uwrapForward p
+        (((T.fromLitString T.mkNoSrcPos p "{")
+            *++
+            (T.uwrapForward p
+              (((T.uwrapForward p
+                    (((gaddCommas T.mkNoSrcPos p)
+                        *$
+                        (T.uwrapForward p (helems fs p))) p))
+                  *++
+                  (T.fromLitString T.mkNoSrcPos p "}")) p))) p)
+      where
+      
+      gaddCommas paddCommas p =
+        T.ufun1 a33v7v35v49addCommas paddCommas p haddCommas
+      
+      aaddCommas = a33v7v35v49addCommas
+      
+      haddCommas (T.R T.List _) p = T.fromLitString T.mkNoSrcPos p ""
+      haddCommas (T.R (T.Cons fx (T.R T.List _)) _) p =
+        T.projection T.mkNoSrcPos p fx
+      haddCommas (T.R (T.Cons fx fxs) _) p =
+        T.uwrapForward p
+          ((fx
+              *++
+              (T.uwrapForward p
+                (((T.fromLitString T.mkNoSrcPos p ",")
+                    *++
+                    (T.uwrapForward p (haddCommas fxs p))) p))) p)
+      haddCommas _ p = T.fatal p
+      
+      gelems pelems p = T.ufun1 a37v7v37v54elems pelems p helems
+      
+      aelems = a37v7v37v54elems
+      
+      helems (T.R (MkSet ffm) _) p =
+        T.uwrapForward p
+          (hmap
+            (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !. p) (gshow T.mkNoSrcPos p)
+              (gfst T.mkNoSrcPos p))
+            (T.uwrapForward p (hfmToList (gfm T.mkNoSrcPos p) p)) p)
+        where
+        
+        gfm pfm p = T.uconstUse pfm p sfm
+        
+        sfm = T.uconstDef p a0v0v0v0fm (\ p -> T.projection T.mkNoSrcPos p ffm)
+        
+      helems _ p = T.fatal p
+      
+    
+  
+
 gemptySet :: T.RefSrcPos -> T.RefExp -> T.R (Set a)
 
 semptySet :: T.R (Set a)
@@ -298,7 +357,7 @@ instance Eq a => Eq ((Set a))
   where
   
   (!==) (%==) p =
-    T.ufun2 (+^%=#^=^%=#@==) (%==) p (*==)
+    T.ufun2 (+@&=#^=@&=#@==) (%==) p (*==)
     where
     
     (*==) (T.R (MkSet fset_1) _) (T.R (MkSet fset_2) _) p =
@@ -320,7 +379,7 @@ instance Eq a => Eq ((Set a))
     
   
   (!/=) (%/=) p =
-    T.ufun2 (+^&=#^=^&=#@/=) (%/=) p (*/=)
+    T.ufun2 (+@*=#^=@*=#@/=) (%/=) p (*/=)
     where
     
     (*/=) (T.R (MkSet fset_1) _) (T.R (MkSet fset_2) _) p =
@@ -346,41 +405,50 @@ tData_Set = T.mkModule "Data.Set" "Data/Set.hs" Prelude.False
 
 aMkSet = T.mkConstructor tData_Set 270017 270021 3 1 "MkSet"
 
-aemptySet = T.mkVariable tData_Set 300001 300024 3 0 "emptySet" Prelude.False
+aemptySet = T.mkVariable tData_Set 410001 410024 3 0 "emptySet" Prelude.False
 
-aunitSet = T.mkVariable tData_Set 330001 330031 3 1 "unitSet" Prelude.False
+aunitSet = T.mkVariable tData_Set 440001 440031 3 1 "unitSet" Prelude.False
 
-asetToList = T.mkVariable tData_Set 360001 360034 3 1 "setToList" Prelude.False
+asetToList = T.mkVariable tData_Set 470001 470034 3 1 "setToList" Prelude.False
 
-amkSet = T.mkVariable tData_Set 390001 390026 3 1 "mkSet" Prelude.False
+amkSet = T.mkVariable tData_Set 500001 500026 3 1 "mkSet" Prelude.False
 
-aunion = T.mkVariable tData_Set 420001 420057 3 2 "union" Prelude.False
+aunion = T.mkVariable tData_Set 530001 530057 3 2 "union" Prelude.False
 
 aunionManySets =
-  T.mkVariable tData_Set 450001 450042 3 1 "unionManySets" Prelude.False
+  T.mkVariable tData_Set 560001 560042 3 1 "unionManySets" Prelude.False
 
-aminusSet = T.mkVariable tData_Set 480001 480061 3 2 "minusSet" Prelude.False
+aminusSet = T.mkVariable tData_Set 590001 590061 3 2 "minusSet" Prelude.False
 
-aintersect = T.mkVariable tData_Set 510001 510066 3 2 "intersect" Prelude.False
+aintersect = T.mkVariable tData_Set 620001 620066 3 2 "intersect" Prelude.False
 
-aaddToSet = T.mkVariable tData_Set 540001 540049 3 2 "addToSet" Prelude.False
+aaddToSet = T.mkVariable tData_Set 650001 650049 3 2 "addToSet" Prelude.False
 
 adelFromSet =
-  T.mkVariable tData_Set 570001 570049 3 2 "delFromSet" Prelude.False
+  T.mkVariable tData_Set 680001 680049 3 2 "delFromSet" Prelude.False
 
-aelementOf = T.mkVariable tData_Set 600001 600048 3 2 "elementOf" Prelude.False
+aelementOf = T.mkVariable tData_Set 710001 710048 3 2 "elementOf" Prelude.False
 
 aisEmptySet =
-  T.mkVariable tData_Set 630001 630040 3 1 "isEmptySet" Prelude.False
+  T.mkVariable tData_Set 740001 740040 3 1 "isEmptySet" Prelude.False
 
-amapSet = T.mkVariable tData_Set 660001 660038 3 2 "mapSet" Prelude.False
+amapSet = T.mkVariable tData_Set 770001 770038 3 2 "mapSet" Prelude.False
 
 acardinality =
-  T.mkVariable tData_Set 690001 690036 3 1 "cardinality" Prelude.False
+  T.mkVariable tData_Set 800001 800036 3 1 "cardinality" Prelude.False
 
-(+^%=#^=^%=#@==) = T.mkVariable tData_Set 730017 730018 16 2 "==" Prelude.False
+a30v3v37v54show = T.mkVariable tData_Set 300003 370054 3 1 "show" Prelude.False
 
-(+^&=#^=^&=#@/=) = T.mkVariable tData_Set 740017 740018 16 2 "/=" Prelude.False
+(+@&=#^=@&=#@==) = T.mkVariable tData_Set 840017 840018 16 2 "==" Prelude.False
+
+(+@*=#^=@*=#@/=) = T.mkVariable tData_Set 850017 850018 16 2 "/=" Prelude.False
+
+a33v7v35v49addCommas =
+  T.mkVariable tData_Set 330007 350049 3 1 "addCommas" Prelude.True
+
+a37v7v37v54elems = T.mkVariable tData_Set 370007 370054 3 1 "elems" Prelude.True
+
+a0v0v0v0fm = T.mkVariable tData_Set 0 0 3 0 "fm" Prelude.True
 
 a0v0v0v0set = T.mkVariable tData_Set 0 0 3 0 "set" Prelude.True
 
