@@ -472,8 +472,7 @@ htry ff p =
         (T.ufun1 T.mkDoLambda T.mkNoSrcPos p
           (\ fr p ->
             T.uap1 T.mkNoSrcPos p (greturn T.mkNoSrcPos p)
-              (T.con1 T.mkNoSrcPos p Right aRight
-                (T.projection T.mkNoSrcPos p fr)))))
+              (T.con1 T.mkNoSrcPos p Right aRight fr))))
       (T.uap2 T.mkNoSrcPos p (T.mkNoSrcPos !. p) (greturn T.mkNoSrcPos p)
         (T.pa0 Left T.cn1 T.mkNoSrcPos p aLeft)) p)
 
@@ -545,16 +544,9 @@ aprimHandleEq = T.mkVariable tIO 350001 360041 3 2 "primHandleEq" Prelude.False
 aprimHandleShowsPrec =
   T.mkVariable tIO 380001 390057 3 3 "primHandleShowsPrec" Prelude.False
 
-(+&$=&=&$=$#==) = T.mkVariable tIO 420004 420021 16 0 "==" Prelude.False
-
-a45v3v45v33showsPrec =
-  T.mkVariable tIO 450003 450033 3 0 "showsPrec" Prelude.False
-
 aprimHandlePosnEq =
   T.mkVariable tIO 490001 500053 3 2 "primHandlePosnEq" Prelude.False
 
-(+*%=&=*%=$*==) = T.mkVariable tIO 530004 530025 16 0 "==" Prelude.False
-
 astdin = T.mkVariable tIO 640001 650016 3 0 "stdin" Prelude.False
 
 astdout = T.mkVariable tIO 660001 670017 3 0 "stdout" Prelude.False
@@ -652,3 +644,10 @@ atry = T.mkVariable tIO 1630001 1650038 3 1 "try" Prelude.False
 abracket = T.mkVariable tIO 1680001 1740031 3 3 "bracket" Prelude.False
 
 abracket_ = T.mkVariable tIO 1780001 1840032 3 3 "bracket_" Prelude.False
+
+(+&$=&=&$=$#==) = T.mkVariable tIO 420004 420021 16 0 "==" Prelude.False
+
+a45v3v45v33showsPrec =
+  T.mkVariable tIO 450003 450033 3 0 "showsPrec" Prelude.False
+
+(+*%=&=*%=$*==) = T.mkVariable tIO 530004 530025 16 0 "==" Prelude.False
