@@ -247,6 +247,76 @@ mkFieldUpdate3(FileOffset parent,FileOffset use
               ,FileOffset binder2,FileOffset bindee2
               ,FileOffset binder3,FileOffset bindee3);
 
+FileOffset
+mkFieldUpdate4(FileOffset parent,FileOffset use
+              ,FileOffset arg,FileOffset binder1,FileOffset bindee1
+              ,FileOffset binder2,FileOffset bindee2
+              ,FileOffset binder3,FileOffset bindee3
+              ,FileOffset binder4,FileOffset bindee4);
+
+FileOffset
+mkFieldUpdate5(FileOffset parent,FileOffset use
+              ,FileOffset arg,FileOffset binder1,FileOffset bindee1
+              ,FileOffset binder2,FileOffset bindee2
+              ,FileOffset binder3,FileOffset bindee3
+              ,FileOffset binder4,FileOffset bindee4
+              ,FileOffset binder5,FileOffset bindee5);
+
+FileOffset
+mkFieldUpdate6(FileOffset parent,FileOffset use
+              ,FileOffset arg,FileOffset binder1,FileOffset bindee1
+              ,FileOffset binder2,FileOffset bindee2
+              ,FileOffset binder3,FileOffset bindee3
+              ,FileOffset binder4,FileOffset bindee4
+              ,FileOffset binder5,FileOffset bindee5
+              ,FileOffset binder6,FileOffset bindee6);
+
+FileOffset
+mkFieldUpdate7(FileOffset parent,FileOffset use
+              ,FileOffset arg,FileOffset binder1,FileOffset bindee1
+              ,FileOffset binder2,FileOffset bindee2
+              ,FileOffset binder3,FileOffset bindee3
+              ,FileOffset binder4,FileOffset bindee4
+              ,FileOffset binder5,FileOffset bindee5
+              ,FileOffset binder6,FileOffset bindee6
+              ,FileOffset binder7,FileOffset bindee7);
+
+FileOffset
+mkFieldUpdate8(FileOffset parent,FileOffset use
+              ,FileOffset arg,FileOffset binder1,FileOffset bindee1
+              ,FileOffset binder2,FileOffset bindee2
+              ,FileOffset binder3,FileOffset bindee3
+              ,FileOffset binder4,FileOffset bindee4
+              ,FileOffset binder5,FileOffset bindee5
+              ,FileOffset binder6,FileOffset bindee6
+              ,FileOffset binder7,FileOffset bindee7
+              ,FileOffset binder8,FileOffset bindee8);
+
+FileOffset
+mkFieldUpdate9(FileOffset parent,FileOffset use
+              ,FileOffset arg,FileOffset binder1,FileOffset bindee1
+              ,FileOffset binder2,FileOffset bindee2
+              ,FileOffset binder3,FileOffset bindee3
+              ,FileOffset binder4,FileOffset bindee4
+              ,FileOffset binder5,FileOffset bindee5
+              ,FileOffset binder6,FileOffset bindee6
+              ,FileOffset binder7,FileOffset bindee7
+              ,FileOffset binder8,FileOffset bindee8
+              ,FileOffset binder9,FileOffset bindee9);
+
+FileOffset
+mkFieldUpdate10(FileOffset parent,FileOffset use
+              ,FileOffset arg,FileOffset binder1,FileOffset bindee1
+              ,FileOffset binder2,FileOffset bindee2
+              ,FileOffset binder3,FileOffset bindee3
+              ,FileOffset binder4,FileOffset bindee4
+              ,FileOffset binder5,FileOffset bindee5
+              ,FileOffset binder6,FileOffset bindee6
+              ,FileOffset binder7,FileOffset bindee7
+              ,FileOffset binder8,FileOffset bindee8
+              ,FileOffset binder9,FileOffset bindee9
+              ,FileOffset binder10,FileOffset bindee10);
+
 FileOffset
 mkProjection(FileOffset parent,FileOffset use,FileOffset exp);
 
