@@ -17,7 +17,7 @@ import SrcRef		(SrcRef(..),readSrcRef,defnSrcRef)
 import SExp		(SExp(..),Label,prettyEquation,prettyExpression
 			,fileNode2SExp,funId,label,QName(..))
 import HighlightStyle	(cursorUp,cleareol,highlight,Highlight(..),Colour(..)
-			,getTerminalSize)
+			,getTerminalSize, hasEscapes)
 import Trie		(Trie,Search(..),emptyTrie,match)
 import TExp		(linearise)
 import Pattern		(topMatchPat,parsePat,lexPat)
@@ -75,11 +75,11 @@ main = do
         state   = initialState hatFile width
     prog <- System.getProgName
     withCString prog (\p-> withCString hatFile (openHatFile p))
-    putStrLn (highlight [Foreground Red] "Loading symbol table...")
+    when hasEscapes $ putStrLn (highlight [Foreground Red] "Loading symbol table...")
     collateIdents
     syms <- getAllIdents
     let state' = state { symbolTable = syms }
-    putStr (cursorUp++cleareol)	-- delayed until next output appears
+    putStr clearLine	-- delayed until next output appears
     case numArgs of
       1 -> interactive state'
       2 -> doCommand (Pattern (arguments!!1)) state'
@@ -94,7 +94,7 @@ main = do
 ----
 showObservation :: InteractiveState -> Int -> FileNode -> IO ()
 showObservation state@(State{options=opts}) i node = do
-  putStr (cursorUp ++ cleareol)	-- delay relies on line-buffered output
+  putStr clearLine  -- delay relies on line-buffered output
   putStrLn (display (screenWidth state) opts node)
   where
   display | equations opts && showRHS state = prettyEquation (show i++" ") ""
@@ -107,11 +107,11 @@ showObservation state@(State{options=opts}) i node = do
 --   exprs :: [FileNode]	roots of equations
 -- result is number of equations that have been shown
 showObservationList :: InteractiveState -> Int -> Int -> [FileNode] -> IO Int
-showObservationList state _ _ [] = do putStr (cursorUp ++ cleareol); return 0
-showObservationList state i 0 _  = do putStr (cursorUp ++ cleareol); return 0
+showObservationList state _ _ [] = do putStr clearLine; return 0
+showObservationList state i 0 _  = do putStr clearLine; return 0
 showObservationList state i max (e:r) = do
     showObservation state i e
-    putStrLn (highlight [Foreground Red] "searching: (^C to interrupt)")
+    beginSearching
     count <- showObservationList state (i+1) (max-1) r
     return (count+1)
 
@@ -174,11 +174,16 @@ showSomeMore state =
   let showNowList = drop (currentPos state) (lastObserved state);
       hasMore = not (null (drop (equationsPerPage state) showNowList))
   in do
-    putStrLn (highlight [Foreground Red] "searching: (^C to interrupt)")
+    beginSearching
     count <- showObservationList state (currentPos state + 1)
 	                         (equationsPerPage state) showNowList
     return (count + currentPos state, hasMore)
 
+beginSearching :: IO ()
+beginSearching = when hasEscapes $ putStrLn (highlight [Foreground Red] "searching: (^C to interrupt)")
+
+clearLine = if hasEscapes then cursorUp++cleareol else ""
+
 interactive :: InteractiveState -> IO ()
 interactive state
     | more state =
@@ -222,7 +227,7 @@ doCommand Quit state =
     else return ()
 doCommand More state =
     if more state then do
-        putStr (cursorUp ++ cleareol)
+        putStr clearLine
         (newPos,newMore) <- showSomeMore state
 	interactive (state {more=newMore,currentPos=newPos})
     else do
@@ -282,7 +287,7 @@ doCommand (Pattern s) state =
       Left str -> do putStrLn ("Error in pattern: "++str)
                      interactive state
       Right p  -> do
-        putStrLn (highlight [Foreground Red] "searching: (^C to interrupt)")
+        beginSearching
         let fun = funId p
             arity p = case p of
                         SApp _ es -> length es - 1
@@ -291,10 +296,10 @@ doCommand (Pattern s) state =
             newObserved = makeObserve state fun ctx p (arity p)
         if isNotFound newObserved || null (fromFound newObserved)
           then do
-            putStrLn (cursorUp ++ cleareol ++ "no match found")
+            putStrLn (clearLine ++ "no match found")
             interactive state
 	  else do
-            putStr (cursorUp ++ cleareol)
+            putStr clearLine
             (newPos,newMore) <- showSomeMore
                                    (state { currentPos=0
                                           , showRHS=not (isCon fun)
@@ -309,10 +314,10 @@ doCommand (Location ss) state =
        let newObserved = makeObserveSrc ss
        if isNotFound newObserved || null (fromFound newObserved)
          then do
-           putStrLn (cursorUp ++ cleareol ++"no match found")
+           putStrLn (clearLine ++"no match found")
            interactive state
          else do
-           putStr (cursorUp ++ cleareol)
+           putStr clearLine
            (newPos,newMore) <- showSomeMore
                                   (state { currentPos=0
                                          , showRHS=True
