@@ -73,19 +73,23 @@ import HighlightStyle     (goto,cls,clearDown,clearUp,cleareol,highlightOff
 --   (FileNode x) < (FileNode y)  = x < y
 --   (FileNode x) > (FileNode y)  = x > y
 
-foreign import ccall getImmediateExpArg :: FileNode -> Int -> FileNode
-foreign import ccall getExpArity   :: FileNode -> Int
+
 getNodeChildren :: FileNode -> [FileNode]
 getNodeChildren n = remove n (map (getImmediateExpArg n) [0..arity])
   where arity = getExpArity n
 
-foreign import ccall getRootNode :: FileNode
-
-foreign import ccall peekResultMod :: FileNode -> FileNode
-
-foreign import ccall getResultHT :: FileNode -> Bool -> FileNode
-
-foreign import ccall nextFileNode :: FileNode -> FileNode
+foreign import ccall "nontermutils.h"
+	getImmediateExpArg :: FileNode -> Int -> FileNode
+foreign import ccall "nontermutils.h"
+	getExpArity   :: FileNode -> Int
+foreign import ccall "nontermutils.h"
+	getRootNode :: FileNode
+foreign import ccall "nontermutils.h"
+	peekResultMod :: FileNode -> FileNode
+foreign import ccall "nontermutils.h"
+	getResultHT :: FileNode -> Bool -> FileNode
+foreign import ccall "nontermutils.h"
+	nextFileNode :: FileNode -> FileNode
 
 
 -- Show the type of a node
@@ -119,16 +123,16 @@ showNodeType node | node <= (FileNode 4)	= "special"
 
 
 -- get a pointer to a the function definition for an expression
-foreign import ccall getFuncPtr :: FileNode -> FileNode
+foreign import ccall "nontermutils.h" getFuncPtr :: FileNode -> FileNode
 
 -- get the name of a function from a NodeApplication
 getFuncName :: FileNode -> String
-foreign import ccall getFuncNm :: FileNode -> CString 
+foreign import ccall "nontermutils.h" getFuncNm :: FileNode -> CString 
 getFuncName n = unsafePerformIO (peekCString (getFuncNm n))
 
 -- get the module of a function from a NodeApplication
 getFuncModule :: FileNode -> String
-foreign import ccall getFuncMod :: FileNode -> CString 
+foreign import ccall "nontermutils.h" getFuncMod :: FileNode -> CString 
 getFuncModule n = unsafePerformIO (peekCString (getFuncMod n))
 
 
@@ -235,11 +239,11 @@ expSrcRef exp = getSrcRef node
 -- Monad functions
 
 -- initialise the counter which counts the number of node accesses 
-foreign import ccall initialiseCount :: IO ()
-foreign import ccall getCount :: Int
+foreign import ccall "nontermutils.h" initialiseCount :: IO ()
+foreign import ccall "nontermutils.h" getCount :: Int
 
 -- increment the node access count by the argument value
-foreign import ccall incCount :: Int -> IO ()
+foreign import ccall "nontermutils.h" incCount :: Int -> IO ()
 incrementCount :: Int -> Bool
 incrementCount x = unsafePerformIO (do incCount x
                                        return True)
@@ -307,6 +311,7 @@ fileNode2SExpMod cutoff uneval strings toplevelLHS label =
     else if node == entered then simple $ SBottom label
     else if node == interrupted then simple $ SInterrupted label
     else if node == lambda then simple $ SLambda label
+    else if node == dolambda then simple $ SDoLambda label
     else
     let r = peekResult node in
     if  r == unevaluated && not (uneval||top) then simple $ SUnevaluated label
@@ -314,6 +319,7 @@ fileNode2SExpMod cutoff uneval strings toplevelLHS label =
     --else if r == entered && not top then simple $ SBottom label
     --else if r == interrupted && top then simple $ SInterrupted label
     else if r == lambda && not uneval then simple $ SLambda label
+    else if r == dolambda && not uneval then simple $ SDoLambda label
     else 
     case simpleNodeType node of
       NodeModule -> "got a Module" `errorAt` node
