@@ -9,6 +9,7 @@
 #include "art.h"
 #include "artutils.h"
 #include "pathutils.h"
+#include "ntohl.h"
 
 #define DEBUG 0
 
@@ -64,7 +65,7 @@ openFile (char* base, char* ext)
   FILE* file;
   strcpy(filename,base);
   strcat(filename,ext);
-  if (file = fopen(filename,"r")) {
+  if (file = fopen(filename,"rb")) {
     return file;
   } else {
     fprintf(stderr,"%s: cannot open %s\n",progname,filename);
@@ -920,7 +921,14 @@ openHatFile (char* prog, char* arg)
   errorRoot = readFO();
   errorMsg  = readFO();
   if (errorMsg==Entered) interrupt=True;
-  signal(SIGINT,SIG_IGN);
+//  signal(SIGINT,SIG_IGN);
+}
+
+void closeHatFile (void)
+{
+  fclose(HatFileRandom);
+  fclose(HatFileSeq);
+  fclose(BridgeFile);
 }
 
 /* Return the contents of the bridge file, one item at a time.  */
