@@ -1,3 +1,9 @@
+#ifndef __NONTERMUTILS_H
+#define __NONTERMUTILS_H
+#include "art.h"
+#include "artutils.h"
+
+
 // filenode manipulators
 FileOffset getRootNode( void );
 FileOffset nextFileNode( FileOffset fo );
@@ -39,3 +45,5 @@ unsigned long foHashFunc ( FOHashTable *table, FileOffset key );
 FileOffset foHashRetrieve (FOHashTable *table, FileOffset key);
 
 extern Bool interrupt;
+
+#endif
